@@ -1,8 +1,10 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import datetime
 from dateutil.relativedelta import relativedelta
 import itertools
+
+from sql import Null
 from sql.aggregate import Sum
 from sql.conditionals import Coalesce
 
@@ -56,6 +58,8 @@ class Forecast(Workflow, ModelSQL, ModelView):
         ('done', 'Done'),
         ('cancel', 'Cancel'),
         ], 'State', readonly=True, select=True)
+    active = fields.Function(fields.Boolean('Active'),
+        'get_active', searcher='search_active')
 
     @classmethod
     def __setup__(cls):
@@ -155,6 +159,33 @@ class Forecast(Workflow, ModelSQL, ModelView):
     def default_company():
         return Transaction().context.get('company')
 
+    def get_active(self, name):
+        pool = Pool()
+        Date = pool.get('ir.date')
+        return self.to_date >= Date.today()
+
+    @classmethod
+    def search_active(cls, name, clause):
+        pool = Pool()
+        Date = pool.get('ir.date')
+
+        today = Date.today()
+        operators = {
+            '=': '>=',
+            '!=': '<',
+            }
+        reverse = {
+            '=': '!=',
+            '!=': '=',
+            }
+        if clause[1] in operators:
+            if clause[2]:
+                return [('to_date', operators[clause[1]], today)]
+            else:
+                return [('to_date', operators[reverse[clause[1]]], today)]
+        else:
+            return []
+
     @classmethod
     def validate(cls, forecasts):
         super(Forecast, cls).validate(forecasts)
@@ -308,13 +339,10 @@ class ForecastLine(ModelSQL, ModelView):
 
     @fields.depends('product')
     def on_change_product(self):
-        res = {}
-        res['unit_digits'] = 2
+        self.unit_digits = 2
         if self.product:
-            res['uom'] = self.product.default_uom.id
-            res['uom.rec_name'] = self.product.default_uom.rec_name
-            res['unit_digits'] = self.product.default_uom.digits
-        return res
+            self.uom = self.product.default_uom
+            self.unit_digits = self.product.default_uom.digits
 
     @fields.depends('product')
     def on_change_with_product_uom_category(self, name=None):
@@ -323,11 +351,9 @@ class ForecastLine(ModelSQL, ModelView):
 
     @fields.depends('uom')
     def on_change_uom(self):
-        res = {}
-        res['unit_digits'] = 2
+        self.unit_digits = 2
         if self.uom:
-            res['unit_digits'] = self.uom.digits
-        return res
+            self.unit_digits = self.uom.digits
 
     def get_unit_digits(self, name):
         return self.product.default_uom.digits
@@ -373,7 +399,7 @@ class ForecastLine(ModelSQL, ModelView):
                             >= forecast.from_date)
                         & (Coalesce(move.effective_date, move.planned_date)
                             <= forecast.to_date)
-                        & (line_move.id == None),
+                        & (line_move.id == Null),
                         group_by=move.product))
                 for product_id, quantity in cursor.fetchall():
                     line = product2line[product_id]
@@ -532,7 +558,7 @@ class ForecastComplete(Wizard):
 
         res = {}
         for field in ("to_date", "from_date"):
-            res[field] = forecast[field] - relativedelta(years=1)
+            res[field] = getattr(forecast, field) - relativedelta(years=1)
         return res
 
     def _get_product_quantity(self):
