@@ -1,20 +1,22 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import unittest
+import doctest
 from decimal import Decimal
 import datetime
 from dateutil.relativedelta import relativedelta
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT, test_view,\
-    test_depends
+from trytond.tests.test_tryton import ModuleTestCase
+from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT
 from trytond.transaction import Transaction
 
 
-class StockForecastTestCase(unittest.TestCase):
+class StockForecastTestCase(ModuleTestCase):
     'Test StockForecast module'
+    module = 'stock_forecast'
 
     def setUp(self):
-        trytond.tests.test_tryton.install_module('stock_forecast')
+        super(StockForecastTestCase, self).setUp()
         self.category = POOL.get('product.category')
         self.uom = POOL.get('product.uom')
         self.template = POOL.get('product.template')
@@ -28,14 +30,6 @@ class StockForecastTestCase(unittest.TestCase):
         self.forecast_complete = POOL.get('stock.forecast.complete',
             type='wizard')
 
-    def test0005views(self):
-        'Test views'
-        test_view('stock_forecast')
-
-    def test0006depends(self):
-        'Test depends'
-        test_depends()
-
     def test0020distribute(self):
         'Test distribute'
         for values, result in (
@@ -216,7 +210,7 @@ def suite():
     suite = trytond.tests.test_tryton.suite()
     from trytond.modules.company.tests import test_company
     for test in test_company.suite():
-        if test not in suite:
+        if test not in suite and not isinstance(test, doctest.DocTestCase):
             suite.addTest(test)
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
             StockForecastTestCase))
